@@ -1,7 +1,11 @@
 #! /usr/bin/env python
 
 import os
+import re
 __path__ = (os.path.dirname(__file__), )
+with open(os.path.join(__path__[0], '__init__.py')) as f:
+    init_text = f.read()
+    __version__ = re.search(r'__version__\s*=\s*[\'\"](.+?)[\'\"]', init_text).group(1)
 import sys
 import json
 import logging
@@ -34,6 +38,7 @@ from argparse import ArgumentParser
 import importlib
 from onnx2tf.utils.colors import Color
 
+
 def convert(
     input_onnx_file_path: Optional[str] = '',
     onnx_graph: Optional[onnx.ModelProto] = None,
@@ -41,6 +46,7 @@ def convert(
     output_signaturedefs: Optional[bool] = False,
     not_use_onnxsim: Optional[bool] = False,
     batch_size: Optional[int] = None,
+    overwrite_input_shape: Optional[List[str]] = None,
     keep_ncw_or_nchw_or_ncdhw_input_names: Optional[List[str]] = None,
     replace_argmax_to_reducemax_and_indicies_is_int64: Optional[bool] = False,
     replace_argmax_to_reducemax_and_indicies_is_float32: Optional[bool] = False,
@@ -50,6 +56,7 @@ def convert(
     replace_power_to_pseudo_power: Optional[bool] = False,
     replace_gathernd_to_pseudo_gathernd: Optional[bool] = False,
     replace_neg_to_pseudo_neg: Optional[bool] = False,
+    replace_hardswish_to_pseudo_hardswish: Optional[bool] = False,
     param_replacement_file: Optional[str] = '',
     mvn_epsilon: Optional[float] = 0.0000000001,
     non_verbose: Optional[bool] = False,
@@ -84,6 +91,18 @@ def convert(
         Fixes the dynamic batch size to the specified numeric batch size.\n
         A value of 1 or more must be specified.
 
+    overwrite_input_shape: Optional[List[str]]
+        Overwrite the input shape.\n
+        The format is\n
+        ["input_name_1:dim0,...,dimN","input_name_2:dim0,...,dimN","input_name_3:dim0,...,dimN"].\n
+        When there is only one input, for example,\n
+        ['data:1,3,224,224']\n
+        When there are multiple inputs, for example,\n
+        ['data1:1,3,224,224','data2:1,3,112,112','data3:5']\n
+        A value of 1 or more must be specified.\n
+        Numerical values other than dynamic dimensions are ignored.\n
+        Ignores --batch_size if specified at the same time as --batch_size.
+
     keep_ncw_or_nchw_or_ncdhw_input_names: Optional[List[str]]
         Holds the NCW or NCHW or NCDHW of the input shape for the specified INPUT OP names.\n
         If a nonexistent INPUT OP name is specified, it is ignored.\n
@@ -121,6 +140,9 @@ def convert(
     replace_neg_to_pseudo_neg: Optional[bool]
         Replace Neg with a pseudo Neg.
 
+    replace_hardswish_to_pseudo_hardswish: Optional[bool]
+        Replace HardSwish with a pseudo HardSwish.
+
     mvn_epsilon: Optional[float]
         For MeanVarianceNormalization.\n
         The number to be added to the variance to avoid division by zero when normalizing the value.\n
@@ -175,6 +197,15 @@ def convert(
         )
         sys.exit(1)
 
+    # overwrite_input_shape
+    if overwrite_input_shape is not None \
+        and not isinstance(overwrite_input_shape, list):
+        print(
+            f'{Color.RED}ERROR:{Color.RESET} ' +
+            f'overwrite_input_shape must be specified by list.'
+        )
+        sys.exit(1)
+
     # replace_argmax_to_reducemax_and_indicies_is_int64
     # replace_argmax_to_reducemax_and_indicies_is_float32
     if replace_argmax_to_reducemax_and_indicies_is_int64 \
@@ -221,7 +252,7 @@ def convert(
                         'onnxsim',
                         f'{input_onnx_file_path}',
                         f'{input_onnx_file_path}'
-                    ],
+                    ] + list(['--overwrite-input-shape'] + overwrite_input_shape) if overwrite_input_shape is not None else [],
                     stderr=subprocess.PIPE
                 ).decode('utf-8')
                 if not non_verbose:
@@ -234,8 +265,8 @@ def convert(
                     f'{Color.YELLOW}WARNING:{Color.RESET} '+
                     'Failed to optimize the onnx file.'
                 )
-                tracetxt = traceback.format_exc().splitlines()[-1]
-                print(f'{Color.YELLOW}WARNING:{Color.RESET} {tracetxt}')
+                import traceback
+                traceback.print_exc()
 
     # Loading Graphs
     # onnx_graph If specified, onnx_graph is processed first
@@ -264,6 +295,7 @@ def convert(
         'replace_power_to_pseudo_power': replace_power_to_pseudo_power,
         'replace_gathernd_to_pseudo_gathernd': replace_gathernd_to_pseudo_gathernd,
         'replace_neg_to_pseudo_neg': replace_neg_to_pseudo_neg,
+        'replace_hardswish_to_pseudo_hardswish': replace_hardswish_to_pseudo_hardswish,
         'replacement_parameters': replacement_parameters,
         'mvn_epsilon': mvn_epsilon,
     }
@@ -438,6 +470,23 @@ def main():
             'Fixes the dynamic batch size to the specified numeric batch size. \n' +
             'A value of 1 or more must be specified.'
     )
+    parser.add_argument(
+        '-ois',
+        '--overwrite_input_shape',
+        type=str,
+        nargs='+',
+        help=\
+            'Overwrite the input shape. \n' +
+            'The format is\n' +
+            '"input_name_1:dim0,...,dimN" "input_name_2:dim0,...,dimN" "input_name_3:dim0,...,dimN". \n' +
+            'When there is only one input, for example, \n' +
+            '"data:1,3,224,224" \n' +
+            'When there are multiple inputs, for example, \n' +
+            '"data1:1,3,224,224" "data2:1,3,112,112" "data3:5" \n' +
+            'A value of 1 or more must be specified. \n' +
+            'Numerical values other than dynamic dimensions are ignored. \n' +
+            'Ignores --batch_size if specified at the same time as --batch_size.'
+    )
     parser.add_argument(
         '-k',
         '--keep_ncw_or_nchw_or_ncdhw_input_names',
@@ -505,6 +554,12 @@ def main():
         action='store_true',
         help='Replace Neg with a pseudo Neg.'
     )
+    parser.add_argument(
+        '-rhs',
+        '--replace_hardswish_to_pseudo_hardswish',
+        action='store_true',
+        help='Replace HardSwish with a pseudo HardSwish.'
+    )
     parser.add_argument(
         '-me',
         '--mvn_epsilon',
@@ -538,6 +593,7 @@ def main():
         output_signaturedefs=args.output_signaturedefs,
         not_use_onnxsim=args.not_use_onnxsim,
         batch_size=args.batch_size,
+        overwrite_input_shape=args.overwrite_input_shape,
         keep_ncw_or_nchw_or_ncdhw_input_names=args.keep_ncw_or_nchw_or_ncdhw_input_names,
         replace_argmax_to_reducemax_and_indicies_is_int64=args.replace_argmax_to_reducemax_and_indicies_is_int64,
         replace_argmax_to_reducemax_and_indicies_is_float32=args.replace_argmax_to_reducemax_and_indicies_is_float32,
@@ -547,6 +603,7 @@ def main():
         replace_power_to_pseudo_power=args.replace_power_to_pseudo_power,
         replace_gathernd_to_pseudo_gathernd=args.replace_gathernd_to_pseudo_gathernd,
         replace_neg_to_pseudo_neg=args.replace_neg_to_pseudo_neg,
+        replace_hardswish_to_pseudo_hardswish=args.replace_hardswish_to_pseudo_hardswish,
         param_replacement_file=args.param_replacement_file,
         mvn_epsilon=args.mvn_epsilon,
         non_verbose=args.non_verbose,
