@@ -57,7 +57,8 @@ def replace_parameter(
     op_rep_params = kwargs.get('op_rep_params', [])
     for op_rep_param in op_rep_params:
         if op_rep_param['param_target'] == param_target \
-            and op_rep_param['param_name'] == param_name:
+            and op_rep_param['param_name'] == param_name \
+            and 'values' in op_rep_param:
             replace_value = op_rep_param.get('values', value_before_replacement)
             if isinstance(value_before_replacement, np.ndarray):
                 replace_value = np.asarray(
@@ -1071,10 +1072,11 @@ def pad_input(
         return input_tensor
 
     # no padding on the NC dimensions
-    tf_paddings = [[0, 0], [0, 0]]
+    tf_paddings = [[0, 0]]
     # padding for the (D)HW dimensions
     for i in range(spatial_size):
         tf_paddings += [[pads[i * 2], pads[i * 2 + 1]]]
+    tf_paddings += [[0, 0]]
 
     padded_tensor = tf.pad(
         input_tensor,
